@@ -4,7 +4,7 @@ from rest_framework.exceptions import ParseError
 from rest_framework.parsers import BaseParser
 
 
-class MsgpackPackParser(BaseParser):
+class MsgpackParser(BaseParser):
     media_type = "application/msgpack"
 
     def parse(self, stream, media_type=None, parser_context=None):
